==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/configure/iedition.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iconfigure.h"

#include "iedition.h"
#include "iobject.h"


#include "istring.h"


void iEdition::ApplySettings(iObject *obj, const iObjectType &type)
{
	if(obj == 0) return;

	iString ws = iEdition::GetObjectSettings(type);
	if(!ws.IsEmpty())
	{
#ifdef I_CHECK1
		bool s = obj->ReportMissingKeys;
		obj->ReportMissingKeys = false;
#endif
		obj->UnPackCompleteState(ws);
#ifdef I_CHECK1
		obj->ReportMissingKeys = s;
#endif
	}
}


#ifndef I_EDITION

const iString iEdition::GetObjectSettings(const iObjectType &)
{
	return "";
}


const iString iEdition::GetEditionName()
{
	return "Standard Edition";
}

#endif

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/configure/iedition.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iconfigure.h"

#include "iedition.h"
#include "iobject.h"


#include "istring.h"


void iEdition::ApplySettings(iObject *obj, const iObjectType &type)
{
	if(obj == 0) return;

	iString ws = iEdition::GetObjectSettings(type);
	if(!ws.IsEmpty())
	{
		obj->ReportMissingKeys(false);
		obj->UnPackCompleteState(ws);
		obj->ReportMissingKeys(true);
	}
}


#ifndef I_EDITION

const iString iEdition::GetObjectSettings(const iObjectType &)
{
	return "";
}


const iString iEdition::GetEditionName()
{
	return "Standard Edition";
}

#endif
